Struct consensus_notifications::ConsensusNotificationResponse [−][src]
The result returned by state sync for a consensus notification.
Fields
result: Result<(), Error>The result returned by state sync for a consensus notification.
result: Result<(), Error>