Trait consensus_notifications::ConsensusNotificationSender[][src]

pub trait ConsensusNotificationSender: Send + Sync {
    fn notify_new_commit<'life0, 'async_trait>(
        &'life0 self,
        transactions: Vec<Transaction>,
        reconfiguration_events: Vec<ContractEvent>
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
    where
        'life0: 'async_trait,
        Self: 'async_trait
;
fn sync_to_target<'life0, 'async_trait>(
        &'life0 self,
        target: LedgerInfoWithSignatures
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
    where
        'life0: 'async_trait,
        Self: 'async_trait
; }
The interface between state sync and consensus, allowing consensus to send synchronization notifications to state sync.

Required methods

Notify state sync of newly committed transactions and reconfiguration events.

Notify state sync to synchronize storage to the specified target.

Implementors