Struct consensus_notifications::ConsensusNotifier [−][src]
pub struct ConsensusNotifier { /* fields omitted */ }Expand description
The consensus component responsible for sending notifications and requests to state sync.
Note: When a ConsensusNotifier instance is created, state sync must take and listen to the receiver in the corresponding ConsensusNotificationListener.